

/*
 * This is a template file. It defines integration functions necessary to complete RTA-BSW.
 * The integrator must complete the templates before deploying software containing functions defined in this file.
 * Once templates have been completed, the integrator should delete the #error line.
 * Note: The integrator is responsible for updates made to this file.
 *
 * To remove the following error define the macro NOT_READY_FOR_TESTING_OR_DEPLOYMENT with a compiler option (e.g. -D NOT_READY_FOR_TESTING_OR_DEPLOYMENT)
 * The removal of the error only allows the user to proceed with the building phase
 */
/* #ifndef NOT_READY_FOR_TESTING_OR_DEPLOYMENT
#error The content of this file is a template which provides empty stubs. The content of this file must be completed by the integrator accordingly to project specific requirements
#else
#warning The content of this file is a template which provides empty stubs. The content of this file must be completed by the integrator accordingly to project specific requirements
#endif */ /* NOT_READY_FOR_TESTING_OR_DEPLOYMENT */


/***************************************************************************************************
* Includes
***************************************************************************************************/
#include "Xcp_Cbk.h"


/***************************************************************************************************
* Variables
***************************************************************************************************/


/***************************************************************************************************
* Functions
***************************************************************************************************/
/* ------------------------------------------------------------------------ */
/* Begin section for code */

#define XCP_START_SEC_CALLOUT_CODE
#include "Xcp_MemMap.h"

#if (XCP_DAQ_STIM_MEMORY_ACCESS_BY_APPL == STD_ON)
/**
****************************************************************************************************
Copy the DAQ data from ecu memory to the destination buffer
\param[in]  AddrPtrDst  destination address
\param[in]  AddrPtrSrc  source address
\param[in]  Length      length of the data to read
\return     -
***************************************************************************************************/
void XcpAppl_OdtEntryRead(Xcp_AdrPtr AddrPtrDst, Xcp_AdrPtrConst AddrPtrSrc, uint8 Length)
{
  /*-----------------------------------------------------------------*/
  /* This function is project specific and shall be totally reworked */
  /*-----------------------------------------------------------------*/

  /* Remove when parameter used */
  XCP_PARAM_UNUSED(AddrPtrDst);
  XCP_PARAM_UNUSED(AddrPtrSrc);
  XCP_PARAM_UNUSED(Length);
}


# if (XCP_SYNCHRONOUS_DATA_STIMULATION_STIM == STD_ON)
/**
****************************************************************************************************
Copy the STIM data from internal buffer to ecu memory
\param[in]  AddrPtrDst  destination address
\param[in]  AddrPtrSrc  source address
\param[in]  Length      length of the data to read
\return     -
***************************************************************************************************/
/* MR12 RULE 8.13 VIOLATION: AddrPtrDst cannot be const as the data is modified */
void XcpAppl_OdtEntryWrite(Xcp_AdrPtr AddrPtrDst, Xcp_AdrPtrConst AddrPtrSrc, uint8 Length)
{
  /*-----------------------------------------------------------------*/
  /* This function is project specific and shall be totally reworked */
  /*-----------------------------------------------------------------*/

  /* Remove when parameter used */
  XCP_PARAM_UNUSED(AddrPtrDst);
  XCP_PARAM_UNUSED(AddrPtrSrc);
  XCP_PARAM_UNUSED(Length);
}

# endif /* (XCP_SYNCHRONOUS_DATA_STIMULATION_STIM == STD_ON) */
#endif /* (XCP_DAQ_STIM_MEMORY_ACCESS_BY_APPL == STD_ON) */

/* ------------------------------------------------------------------------ */
/* End section for code */

#define XCP_STOP_SEC_CALLOUT_CODE
#include "Xcp_MemMap.h"

